==> nextcloud-29.0.12.tgz: nextcloud/apps/notifications/l10n/et_EE.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Soovime jätkuvalt pakkuda tasuta tõuke-teavitusteenust, kuid suur hulk kasutajaid koormab meie infrastruktuuri üle. Sel põhjusel peame tõukemärguannete kasutamist piirama. Kui vajate seda funktsiooni, kaaluge Nextcloud Enterprise'i kasutamist.",
    "User not found" : "Kasutajat ei leitud",
    "An unexpected error occurred, ask your administration to check the logs." : "Ilmnes ootamatu tõrge, palu administratsioonil logisid kontrollida.",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Uus teavitus %s kohta","%n uut teavitust %s kohta"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Sul on uus teavitus %s kohta","Sul on %n uut teavitust %s kohta"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Saad muuta nende emailide sagedust või neid välja lülitada <a href=\"%s\">seadetes</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Saad muuta nende emailide sagedust või neid välja lülitada seadetes: %s",
    "Admin notifications" : "Admini teavitused",
    "Notifications" : "Märguanded",
    "Push notifications - Fair use policy" : "Tõuketeavitused - Õiglase kasutamise poliitika",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH sponsoreerib erakasutajatele tasuta tõuke-teavituste lüüsi. Hea teeninduse tagamiseks piirab lüüs tõuketeatiste arvu serveri kohta ja selle serveri limiit saavutati. Ettevõtluskasutajatele on saadaval skaleeritavam lüüs.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "See rakendus pakub Nextcloudis saadaolevale teavitus-API-le tausta- ja esiprogrammi.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "See rakendus pakub Nextcloudis saadaolevale teavitus-API-le tausta- ja esiprogrammi.\nTeised rakendused kasutavad API-d kasutajate teavitamiseks veebi kasutajaliideses ja klientide sünkroonimiseks mitmesugustest asjadest. Mõned näited on järgmised:\n\n📬 Ühendatud failijagamine: saite uue kaugjagamise\n\n📑 Kommentaarid: teine ​​kasutaja mainis teid faili kommentaaris\n\n🚢 Värskendamise teatis: saadaval värskendus rakenduse või nextcloudi enda jaoks\n\n📣 Teadetekeskus: Administraator postitas teadaande",
    "Failed to perform action" : "Tegevuse läbiviimine ebaõnnestus",
    "Dismiss" : "Jäta vahele",
    "Contact Nextcloud GmbH" : "Võta ühendust Nextcloud GmbH-ga",
    "seconds ago" : "sekundit tagasi",
    "Failed to dismiss notification" : "Teavituse eiramine ebaõnnestus",
    "in {path}" : "rajal {path}",
    "Dismiss all notifications" : "Eira kõiki teavitusi",
    "Requesting browser permissions to show notifications" : "Küsime brauserilt luba teavituste näitamiseks",
    "Push notifications might be unreliable" : "Tõuketeavitused võivad olla ebakindlad",
    "No notifications" : "Märguandeid pole",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH sponsoreerib erakasutajatele tasuta tõuke-teavituste lüüsi. Hea teeninduse tagamiseks piirab lüüs tõuketeatiste arvu serveri kohta. Ettevõtluskasutajatele on saadaval skaleeritavam lüüs. Lisateabe saamiseks võtke ühendust Nextcloud GmbH-ga.",
    "Failed to dismiss all notifications" : "Kõikide teavituste eiramine ebaõnnestus",
    "Notifications defaults" : "Teavituse vaikesätted",
    "Configure the default notification settings for new users" : "Sea üles uutele kasutajatele teavituste vaikesätted",
    "Send email reminders about unhandled notifications after:" : "Saada emaili meeldetuletus reageerimata teavituste kohta peale:",
    "Play sound when a new notification arrives" : "Mängi heli kui uus saabub uus teavitus",
    "Play sound when a call started (requires Nextcloud Talk)" : "Mängi heli kõne alguses (vajab Nextcloud Talki)",
    "Never" : "Mitte kunagi",
    "1 hour" : "1 tund",
    "3 hours" : "3 tundi",
    "1 day" : "1 päev",
    "1 week" : "1 nädal",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "An error occurred while updating your settings." : "Sättete uuendamisel esines tõrge.",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Also repeat sound on a secondary speaker" : "Lisaks korda heli tagavara kõlaril",
    "Selection of the speaker device is currently not supported by Safari" : "Kõlariseadme valimine ei ole hetkel Safaril toetatud",
    "Select a device" : "Vali seade",
    "None" : "Pole"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.10.tgz: nextcloud/apps/notifications/l10n/et_EE.js <==
OC.L10N.register(
    "notifications",
    {
    "We want to keep offering our push notification service for free, but large number of users overload our infrastructure. For this reason we have to rate-limit the use of push notifications. If you need this feature, consider using Nextcloud Enterprise." : "Soovime jätkuvalt pakkuda tasuta tõuketeavituste teenust, kuid suur hulk kasutajaid koormab meie infrastruktuuri üle. Sel põhjusel peame tõuketeavituste kasutamist piirama. Kui vajad seda funktsioonaalsust, siis kaalu Nextcloud Enterprise'i kasutamist.",
    "User not found" : "Kasutajat ei leitud",
    "An unexpected error occurred, ask your administration to check the logs." : "Ilmnes ootamatu tõrge, palu administratsioonil logisid kontrollida.",
    "Hello %s" : "Tere %s",
    "Hello %s," : "Tere %s,",
    "_New notification for %s_::_%n new notifications for %s_" : ["Uus teavitus %s kohta","%n uut teavitust %s kohta"],
    "_You have a new notification for %s_::_You have %n new notifications for %s_" : ["Sul on uus teavitus %s kohta","Sul on %n uut teavitust %s kohta"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Saad muuta nende emailide sagedust või neid välja lülitada <a href=\"%s\">seadetes</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Saad muuta nende emailide sagedust või neid välja lülitada seadetes: %s",
    "Admin notifications" : "Admini teavitused",
    "Notifications" : "Märguanded",
    "Push notifications - Fair use policy" : "Tõuketeavitused - Õiglase kasutamise poliitika",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server and the limit was reached for this server. For enterprise users, a more scalable gateway is available." : "Nextcloud GmbH rahastab tasuta tõuketeavituste lüüsi erakasutuseks. Hea teeninduse tagamiseks piirab lüüs tõuketevituste arvu serveri kohta ja selle serveri ülempiir on käes. Ettevõtluskasutajatele on saadaval skaleeritavam lüüs.",
    "This app provides a backend and frontend for the notification API available in Nextcloud." : "See rakendus pakub Nextcloudis saadaolevale teavitus-API-le tausta- ja esiprogrammi.",
    "This app provides a backend and frontend for the notification API available in Nextcloud.\n\t\tThe API is used by other apps to notify users in the web UI and sync clients about various things. Some examples are:\n\n📬 Federated file sharing: You received a new remote share\n\n📑 Comments: Another user mentioned you in a comment on a file\n\n🚢 Update notification: Available update for an app or nextcloud itself\n\n📣 Announcement center: An announcement was posted by an admin" : "See rakendus pakub Nextcloudis saadaolevale teavitus-API-le tausta- ja esiprogrammi.\nTeised rakendused kasutavad API-d kasutajate teavitamiseks veebi kasutajaliideses ja klientide sünkroonimiseks mitmesugustest asjadest. Mõned näited on järgmised:\n\n📬 Ühendatud failijagamine: saite uue kaugjagamise\n\n📑 Kommentaarid: teine ​​kasutaja mainis teid faili kommentaaris\n\n🚢 Värskendamise teatis: saadaval värskendus rakenduse või nextcloudi enda jaoks\n\n📣 Teadetekeskus: Administraator postitas teadaande",
    "Failed to perform action" : "Tegevuse läbiviimine ebaõnnestus",
    "seconds ago" : "sekundit tagasi",
    "Failed to dismiss notification" : "Teavituse eiramine ebaõnnestus",
    "Dismiss" : "Jäta vahele",
    "Contact Nextcloud GmbH" : "Võta ühendust Nextcloud GmbH-ga",
    "in {path}" : "rajal {path}",
    "Requesting browser permissions to show notifications" : "Küsime brauserilt luba teavituste näitamiseks",
    "Push notifications might be unreliable" : "Tõuketeavitused võivad olla ebakindlad",
    "No notifications" : "Märguandeid pole",
    "Nextcloud GmbH sponsors a free push notification gateway for private users. To ensure good service, the gateway limits the number of push notifications per server. For enterprise users, a more scalable gateway is available. Contact Nextcloud GmbH for more information." : "Nextcloud GmbH rahastab tasuta tõuketeavituste lüüsi erakasutuseks. Hea teeninduse tagamiseks piirab lüüs tõuketevituste arvu serveri kohta. Ettevõtluskasutajatele on saadaval skaleeritavam lüüs. Lisateabe saamiseks võta ühendust Nextcloud GmbH-ga.",
    "Failed to dismiss all notifications" : "Kõikide teavituste eiramine ebaõnnestus",
    "Dismiss all notifications" : "Eira kõiki teavitusi",
    "Never" : "Mitte kunagi",
    "1 hour" : "1 tund",
    "3 hours" : "3 tundi",
    "1 day" : "1 päev",
    "1 week" : "1 nädal",
    "Your settings have been updated." : "Seaded on uuendatud.",
    "An error occurred while updating your settings." : "Sättete uuendamisel esines tõrge.",
    "Notifications defaults" : "Teavituse vaikesätted",
    "Configure the default notification settings for new users" : "Sea üles uutele kasutajatele teavituste vaikesätted",
    "Send email reminders about unhandled notifications after:" : "Saada emaili meeldetuletus reageerimata teavituste kohta peale:",
    "Play sound when a new notification arrives" : "Mängi heli kui uus saabub uus teavitus",
    "Play sound when a call started (requires Nextcloud Talk)" : "Mängi heli kõne alguses (vajab Nextcloud Talki)",
    "None" : "Pole",
    "You need to set up your email address before you can receive notification emails." : "Enne teavituskirjade saamist pead sa lisama oma e-posti aadressi.",
    "Also repeat sound on a secondary speaker" : "Lisaks korda heli tagavara kõlaril",
    "Selection of the speaker device is currently not supported by Safari" : "Kõlariseadme valimine ei ole hetkel Safaril toetatud",
    "Select a device" : "Vali seade"
},
"nplurals=2; plural=(n != 1);");
